/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of PeerfactSim.KOM.
 * 
 * PeerfactSim.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tud.kom.p2psim.impl.topology.movement.modularosm.attraction;

import java.util.LinkedList;
import java.util.List;
import java.util.Random;
import de.tud.kom.p2psim.api.scenario.ConfigurationException;
import de.tud.kom.p2psim.api.topology.Topology;
import de.tud.kom.p2psim.impl.topology.util.PositionVector;
import de.tudarmstadt.maki.simonstrator.api.Binder;
import de.tudarmstadt.maki.simonstrator.api.Event;
import de.tudarmstadt.maki.simonstrator.api.EventHandler;
import de.tudarmstadt.maki.simonstrator.api.Randoms;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.IAttractionPoint;
import de.tudarmstadt.maki.simonstrator.api.util.XMLConfigurableConstructor;

/**
 * Implementation of the interface {@link AttractionGenerator}.
 * 

 * @author Julian Zobel
 * @version 1.0, April 2019
 */
public class ConfigDynamicAttractionGenerator implements IAttractionGenerator {

	private LinkedList<TemporalAttractionPoint> allAPs = new LinkedList<>();

	@Override
	public List<IAttractionPoint> getAttractionPoints() {		
		return attractionPoints;
	}
		
		
		
	public void setAttractionPoint(TemporalAttractionPoint ap) {
		allAPs.add(ap);
		
		Event.scheduleWithDelay(ap.getPlacementTime(), new EventHandler() {
			@Override
			public void eventOccurred(Object content, int type) {
				placeAP(ap);
			}
		}, null, 0);
	}
	
	private void placeAP(TemporalAttractionPoint ap) {
		attractionPoints.add(ap);
		
		
		Event.scheduleWithDelay(ap.getRemovalTime(), new EventHandler() {
			@Override
			public void eventOccurred(Object content, int type) {
				removeAP(ap);
			}
		}, null, 0);
	}

	private void removeAP(TemporalAttractionPoint ap) {
		attractionPoints.remove(ap);
	}
	
	
}
