/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of PeerfactSim.KOM.
 * 
 * PeerfactSim.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tud.kom.p2psim.impl.topology.movement.modularosm.attraction;

import java.util.List;
import de.tud.kom.p2psim.api.topology.Topology;
import de.tud.kom.p2psim.impl.topology.util.PositionVector;
import de.tudarmstadt.maki.simonstrator.api.Binder;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.IAttractionPoint;
import de.tudarmstadt.maki.simonstrator.api.util.XMLConfigurableConstructor;

/**
 * Implementation of the interface {@link AttractionGenerator}.
 * 
 * Generates the given number of {@link IAttractionPoint}s and sets the
 * position randomly within the world dimensions.
 * 
 * @author  Julian Zobel
 * @version 1.0, Nov 2018
 */
public class EquidistantSquareAttractionGenerator implements IAttractionGenerator {

	private PositionVector worldDimension;
	private double squareSize;
	
	@XMLConfigurableConstructor({ "squareSize" })
	public EquidistantSquareAttractionGenerator(double squareSize) {
		
		this.worldDimension = Binder.getComponentOrNull(Topology.class)
				.getWorldDimensions();
				
		this.squareSize = squareSize;
		createAttractionPoints();
	}

	@Override
	public List<IAttractionPoint> getAttractionPoints() {
		if(attractionPoints.isEmpty())
			createAttractionPoints();
		
		return attractionPoints;
	}
	
	private void createAttractionPoints() {
						
		double x = worldDimension.getX() / 2;
		double y = worldDimension.getY() / 2;
		
		PositionVector p1 = new PositionVector(x - squareSize, y - squareSize);		
		IAttractionPoint ap1 = new AttractionPointImpl("AP1", p1);
		attractionPoints.add(ap1);
		
		PositionVector p2 = new PositionVector(x - squareSize, y + squareSize);		
		IAttractionPoint ap2 = new AttractionPointImpl("AP2", p2);
		attractionPoints.add(ap2);
		
		PositionVector p3 = new PositionVector(x + squareSize, y - squareSize);		
		IAttractionPoint ap3 = new AttractionPointImpl("AP3", p3);
		attractionPoints.add(ap3);
		
		PositionVector p4 = new PositionVector(x + squareSize, y + squareSize);		
		IAttractionPoint ap4 = new AttractionPointImpl("AP4", p4);
		attractionPoints.add(ap4);
	}

	
}
